#[unsafe(no_mangle)]pub unsafe extern "C" fn haystack_value_is_na(
val: *const Value,
) -> boolExpand description
Arguments
val a Value.
Returns
True, or False in which case if argument type mismatch an error is created that can be read using last_error_message
Example
let val = haystack_value_make_na();
assert!(!haystack_value_is_null(val));
assert!(haystack_value_is_na(val));Safety
Panics on invalid input data