Module timezone

Module timezone 

Haystack timezone support, with fallback to UTC.

This module can be configured to work with the full IANA database provided by chrono_tz, or by just using a fixed offset datetime by toggling the timezone feature.

Re-exports

pub use iana::*;

Modules

iana
Haystack Timezone configured to work with the full IANA database provided by chrono_tz.