Module units

Module units 

Haystack Units module

Re-exports

pub use unit::Unit;
pub use unit_dimension::UnitDimensions;

Modules

unit
Haystack Unit types
unit_dimension
Haystack Unit Dimension type
units_generated

Structs

DEFAULT_UNIT
The dimensionless default unit

Functions

get_unit
Get unit by name, if it is defined in the units database
get_unit_or_default
Tries to get the unit by name, if none is found, return a default unit
match_units
Match units for the dimension