pub struct Marker;Expand description
Haystack Marker
Example
Create Marker value
use libhaystack::val::*;
let marker_value = Value::from(Marker);
assert!(marker_value.is_marker());
assert_eq!(Marker::try_from(&marker_value), Ok(Marker));Trait Implementations
sourceimpl<'de> Deserialize<'de> for Marker
impl<'de> Deserialize<'de> for Marker
Hayson Marker deserializer
sourcefn deserialize<D: Deserializer<'de>>(
deserializer: D
) -> Result<Marker, D::Error>
fn deserialize<D: Deserializer<'de>>(
deserializer: D
) -> Result<Marker, D::Error>
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Ord for Marker
impl Ord for Marker
sourceimpl PartialOrd<Marker> for Marker
impl PartialOrd<Marker> for Marker
sourcefn partial_cmp(&self, other: &Marker) -> Option<Ordering>
fn partial_cmp(&self, other: &Marker) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Copy for Marker
impl Eq for Marker
impl StructuralEq for Marker
impl StructuralPartialEq for Marker