pub struct Remove;Expand description
Haystack Remove
Example
Create Remove value
use libhaystack::val::*;
let remove_value = Value::from(Remove);
assert!(remove_value.is_remove());
assert_eq!(Remove::try_from(&remove_value), Ok(Remove));Trait Implementations
sourceimpl<'de> Deserialize<'de> for Remove
impl<'de> Deserialize<'de> for Remove
Hayson Remove deserializer
sourcefn deserialize<D: Deserializer<'de>>(
deserializer: D
) -> Result<Remove, D::Error>
fn deserialize<D: Deserializer<'de>>(
deserializer: D
) -> Result<Remove, D::Error>
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Ord for Remove
impl Ord for Remove
sourceimpl PartialOrd<Remove> for Remove
impl PartialOrd<Remove> for Remove
sourcefn partial_cmp(&self, other: &Remove) -> Option<Ordering>
fn partial_cmp(&self, other: &Remove) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Copy for Remove
impl Eq for Remove
impl StructuralEq for Remove
impl StructuralPartialEq for Remove