pub enum Value {
Show 18 variants Null, Remove, Marker, Bool(Bool), Na, Number(Number), Str(Str), Uri(Uri), Ref(Ref), Symbol(Symbol), Date(Date), Time(Time), DateTime(DateTime), Coord(Coord), XStr(XStr), List(List), Dict(Dict), Grid(Grid),
}
The Value object is the universal type that can have any of supported tag values specified by the Project Haystack 4.0 spec.

It is implemented as an Algebraic type (enum) than can be constructed from build-in types, such as bool or i32, and dedicated Haystack types such as Str

Usage

Creating a scalar Haystack number value

use libhaystack::val::*;
use libhaystack::units::get_unit_or_default;

let num = Value::make_number_unit(42.0, get_unit_or_default("°F"));

assert!(num.is_number());
assert_eq!(Number::try_from(&num).unwrap().unit, Some(get_unit_or_default("°F")));

Creating complex structures such as a Dict

use libhaystack::dict;
use libhaystack::val::*;

let dict = Value::make_dict(dict!("strTagName" => Value::from("Str Tag value"),
                 "marker" => Value::make_marker()));
assert!(dict.is_dict());

Creating a Haystack Grid

use libhaystack::dict;
use libhaystack::val::*;

let grid = Value::make_grid_from_dicts(vec![
    dict!("dis" => Value::from("First dict row"),
          "id" => Value::make_ref_gen()),
    dict!("dis" => Value::from("Second dict row"),
          "id" => Value::make_ref_gen())
]);
assert!(grid.is_grid());
assert_eq!(Grid::try_from(&grid).unwrap().len(), 2);

Variants

Null

No value

Remove

A remove tag

Marker

Marker tag

Bool(Bool)

Bool true/false

Na

Na tag

Number(Number)

Number floating point value and optional unit

Str(Str)

Uri(Uri)

URI with string value

Ref(Ref)

Ref with string value

Symbol(Symbol)

A symbol with string value

Date(Date)

Date year, month, date

Time(Time)

Time hour, minutes, seconds with optional millis

DateTime(DateTime)

DateTime date, time and timezone

Coord(Coord)

Coordinate latitude and longitude

XStr(XStr)

XStr with type and value

List(List)

List of tags

Dict(Dict)

Dictionary of String key and Value values

Grid(Grid)

Haystack Grid

Implementations

Implements the utility functions for creating and getting the current type

True if this Value is a haystack Null

True if this Haystack Value is not null

Construct a Remove Value

True if this Value is a haystack Remove

Construct a Marker Value

True if this Value is a haystack Marker

Construct a Bool Value

Construct a Bool ‘true’ Value

True if Value is a true (Bool)crate::val::Bool

True if Value is a false (Bool)crate::val::Bool

Construct a Bool ‘false’ Value

Construct a Na Value

True if this Value is a haystack Na

Construct a Number Value from a floating point value

Construct a Number Value from a integer value

Construct a Number Value with an unit

True if this Value is a haystack Number

Construct a Str Value from a string

True if this Value is a haystack Str

Construct a Ref Value from a string

Construct a Ref Value by generating an unique Ref

Construct a Ref Value from a string with a display name

True if this Value is a haystack Ref

Construct a Symbol Value from a string

True if this Value is a haystack Symbol

Construct a Uri Value from a string

True if this Value is a haystack Uri

Construct a Date Value from a Date

True if this Value is a haystack Date

Construct a Time Value from a Time

True if this Value is a haystack Time

Construct a DateTime Value from a DateTime

Try to construct a DateTime Value from a string

True if this Value is a haystack DateTime

Construct a Coord Value from a Coord

Construct a Coord Value from a latitude and longitude

True if this Value is a haystack Coord

Construct a XStr Value from a XStr

Construct a XStr Value from a type and value

True if this Value is a haystack XStr

Construct a List Value from a List

True if this Value is a haystack List

Construct a Dict Value from a Dict

True if this Value is a haystack Dict

Construct a Grid Value from a Grid

Construct a Grid Value from a list of Dicts

True if this Value is a haystack `Dict