Haystack Units module
Re-exports
pub use unit::Unit;pub use unit_dimension::UnitDimensions;
Modules
- unit
- Haystack Unit types
- unit_
dimension - Haystack Unit Dimension type
- units_
generated
Structs
- DEFAULT_
UNIT - The dimensionless default unit
Functions
- get_
unit - Get unit by name, if it is defined in the units database
- get_
unit_ or_ default - Tries to get the unit by name, if none is found, return a default unit
- match_
units - Match units for the dimension